@@ -26,7 +26,7 @@ from synapse.module_api import ModuleApi
 from synapse.types import JsonDict
 from twisted.internet import threads
 
-__version__ = "0.2.1"
+__version__ = "0.2.2"
 
 logger = logging.getLogger(__name__)
 
@@ -133,8 +133,6 @@ class LdapAuthProvider:
             except ActiveDirectoryUPNException:
                 return None
 
-        localpart = localpart.lower()
-
         try:
             server = self._get_server()
             logger.debug("Attempting LDAP connection with %s", self.ldap_uris)
@@ -188,11 +186,12 @@ class LdapAuthProvider:
             user_id = self.account_handler.get_qualified_user_id(localpart)
 
             # check if user with user_id exists
-            if await self.account_handler.check_user_exists(user_id):
+            canonical_user_id = await self.account_handler.check_user_exists(user_id)
+            if canonical_user_id:
                 # exists, authentication complete
                 if hasattr(conn, "unbind"):
                     await threads.deferToThread(conn.unbind)
-                return user_id
+                return canonical_user_id
 
             else:
                 # does not exist, register
@@ -225,7 +224,9 @@ class LdapAuthProvider:
                     mail = None
 
                 # Register the user
-                user_id = await self.register_user(localpart, display_name, mail)
+                user_id = await self.register_user(
+                    localpart.lower(), display_name, mail
+                )
 
                 return user_id
 
